### Name: simint
### Title: Simultaneous Confidence Intervals
### Aliases: simint simint.default simint.formula simint.lm simint.glm
### Keywords: htest

### ** Examples

data(recovery)

# one-sided simultaneous confidence intervals for Dunnett 
# in the one-way layout
summary(simint(minutes~blanket, data=recovery, type="Dunnett", 
               conf.level=0.9, alternative="less",eps=0.0001))

# alternatively via a prespecified linear model
lmmod <- lm(minutes ~ blanket, data=recovery, contrasts=list(blanket =
            "contr.Dunnett"))
summary(simint(lmmod, psubset=2:4, conf.level=0.9,
               alternative="less",eps=0.0001))

# Tukey confidence intervals, compare with TukeyHSD

data(warpbreaks)
fm1 <- aov(breaks ~ wool + tension, data = warpbreaks)
tHSD <- TukeyHSD(fm1, "tension", ordered = FALSE)
print(tHSD)

mcHSD <- simint(breaks ~ wool + tension, data = warpbreaks, 
                whichf="tension", type="Tukey")
print(mcHSD)
plot(mcHSD)

## Don't show:
  tlow <- tHSD$tension[,2]
  tupp <- tHSD$tension[,3]
  mclow <- mcHSD$conf.int[,1]
  mcupp <- mcHSD$conf.int[,2]

  a <- round(tlow, 1) 
  b <- round(mclow, 1)
  names(a) <- NULL
  names(b) <- NULL
  stopifnot(all.equal(a, b))

  a <- round(tupp, 1) 
  b <- round(mcupp, 1)
  names(a) <- NULL
  names(b) <- NULL
  stopifnot(all.equal(a, b))
## End Don't show




